#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.2
visibility:           public
id:                   HTF-0.15.0.2-8BXhaSvuiq744m6UN8AHEf
key:                  HTF-0.15.0.2-8BXhaSvuiq744m6UN8AHEf
license:              LGPL-2.1-only
copyright:            (c) 2005-2024 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  a95c96073ccc0667fbd39c0768a7f6b6
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HTF-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.2-8BXhaSvuiq744m6UN8AHEf
depends:
    Diff-0.5-1NGQ2AwAw3pDIUtg9aS2pi
    HUnit-1.6.2.0-8Wn6BBwQEu19q9UZBWMuwr
    QuickCheck-2.15.0.1-F3yDOVYG0n1GiUlgvE4tmI
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy array-0.5.6.0 base-4.18.2.1
    base64-bytestring-1.2.1.0-746voJok0ldKgJVOvUeNqZ
    bytestring-0.11.5.3 containers-0.6.7
    cpphs-1.20.9.1-24V9xcsZlOA6VFsNCn4tMO directory-1.3.8.5
    haskell-src-1.0.4.2-5nRYk5nNc8aK4BKeA3HIoV
    lifted-base-0.2.3.12-BbJ6wmOAthNAy8ef9PCYeT
    monad-control-1.0.3.1-8XFERMcv7kkBnFgtt0dteN mtl-2.3.1
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx pretty-1.1.3.6
    process-1.6.19.0 random-1.2.1.3-3jem7NfN1E34SkjZGu3Vjy
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag text-2.0.2 time-1.12.2
    unix-2.8.4.0 vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE
    xmlgen-0.6.2.2-J5VBVEAuQkN5lPUFAEvPCU

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

